@@ -4,7 +4,6 @@ import os
 extensions = [
     'sphinx.ext.autodoc',
     'sphinx.ext.autosummary',
-    'sphinx.ext.doctest',
     'sphinx.ext.todo',
     'sphinx.ext.coverage',
     'sphinx.ext.ifconfig',
@@ -19,21 +18,25 @@ if os.getenv('SPELLCHECK'):
 source_suffix = '.rst'
 master_doc = 'index'
 project = u'Nameless'
-copyright = u'2014, Ionel Cristian Mărieș'
+copyright = u'2014, Ionel Cristian Maries'
 version = release = re.findall(
     'version="(.*)"',
     open(os.path.join(os.path.dirname(__file__), '../setup.py')).read()
 )[0]
 
-html_theme = 'pydoctheme'
-html_theme_path = ['.']
+import sphinx_py3doc_enhanced_theme
+html_theme = "sphinx_py3doc_enhanced_theme"
+html_theme_path = [sphinx_py3doc_enhanced_theme.get_html_theme_path()]
+
 pygments_style = 'trac'
 templates_path = ['.']
 html_use_smartypants = True
 html_last_updated_fmt = '%b %d, %Y'
-exclude_trees = ['pydoctheme']
 html_split_index = True
 html_sidebars = {
    '**': ['searchbox.html', 'globaltoc.html', 'sourcelink.html'],
 }
-html_short_title = '%s-%s' % (project, version)
\ No newline at end of file
+html_short_title = '%s-%s' % (project, version)
+html_theme_options = {
+    'githuburl': 'https://github.com/ionelmc/python-nameless/'
+}
